<?php

/**
 * @package    WPBuddy Plugin
 * @subpackage Google+ Author
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

/**
 * @since 1.0
 */
class WPB_Google_Author_Widget extends WP_Widget {


	/**
	 * __construct function.
	 *
	 * @access public
	 * @return \WPB_Google_Author_Widget
	@since 1.0
	 */
	public function __construct() {
		parent::__construct(
			'gpaisrpro_widget',
			__( 'Google+ Author', 'gpaisrpro' ),
			array( 'description' => __( 'Add the Google+ Authorship Link to your sidebar.', 'gpaisrpro' ) )
		);
	}


	/**
	 * Front-end display of widget.
	 *
	 * @see   WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 *
	 * @return string|void
	 * @since 1.0
	 */
	function widget( $args, $instance ) {

		// get the options
		$options = get_option( 'gpaisrpro' );

		// if nothing was set: posts and pages are standard
		if ( ! isset( $options['post_types'] ) ) {
			$options['post_types'] = array( 'post', 'page' );
		}

		global $post;

		// if the current post type does not match the selected ones, just return the link
		if ( ! in_array( $post->post_type, $options['post_types'] ) ) {
			return '';
		}

		extract( $args );

		global $wpb_google_author;
		$linktext = $wpb_google_author->author_link_in_content( '' );

		$title = ( ( ! isset( $instance['title'] ) ) ? '' : $instance['title'] );
		$title = apply_filters( 'widget_title', $title );

		echo $before_widget;
		echo $before_title . $title . $after_title;
		echo $linktext;
		echo $after_widget;
	}


	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see   WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		$options = get_option( 'gpaisrpro' );

		$new_window = 1;
		if ( ! isset( $new_instance['new_window'] ) ) {
			$new_window = 0;
		}

		// set new options
		$options['new_window'] = $new_window;
		$options['link_text']  = $new_instance['link_text'];

		// save new options
		update_option( 'gpaisrpro', $options );

		// as a standard, WordPress does not allow html tags here so strip it as well
		$new_instance['title'] = strip_tags( $new_instance['title'] );

		return $new_instance;
	}

	/**
	 * @param array $instance
	 *
	 * @return string|void
	 * @since 1.0
	 */
	function form( $instance ) {
		$options  = get_option( 'gpaisrpro' );
		$linktext = esc_attr( ( ( ! isset( $instance['linktext'] ) ) ? 'Google+' : $instance['linktext'] ) );
		$title    = esc_attr( ( ( ! isset( $instance['title'] ) ) ? __( 'Google+ Author', 'gpaisrpro' ) : $instance['title'] ) );
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'new_window' ); ?>"><?php echo __( 'Open the link in a new window?', 'gpaisrpro' ); ?></label>
			<input type="checkbox" name="<?php echo $this->get_field_name( 'new_window' ); ?>" value="1" id="<?php echo $this->get_field_id( 'new_window' ); ?>" <?php if ( isset( $options['new_window'] ) && $options['new_window'] == 1 ) {
				echo 'checked="checked"';
			} ?> />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'link_text' ); ?>"><?php echo __( 'Link text', 'gpaisrpro' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'link_text' ); ?>" value="<?php if ( ! isset( $options['link_text'] ) ) {
				echo 'Google+';
			}
			else {
				echo esc_attr( $options['link_text'] );
			} ?>" class="widefat" id="<?php echo $this->get_field_id( 'link_text' ); ?>" />
		</p>

	<?php
	}

}
